@@ -11,7 +11,7 @@
 #'
 fair_init <- function(name,
                       identifier,
-                      endpoint = "http://localhost:8000/api/") {
+                      endpoint = "http://127.0.0.1:8000/api/") {
 
   user_url <- get_url(table = "users",
                       query = list(username = "admin"),
