@@ -10,7 +10,7 @@
 get_dataproduct <- function(data_product,
                             version,
                             namespace,
-                            endpoint = "http://localhost:8000/api/") {
+                            endpoint = "http://127.0.0.1:8000/api/") {
   # Get provenance URL
   namespace_entry <- get_entry("namespace",
                                list(name = namespace),
