@@ -1,6 +1,8 @@
 #' Get ID
 #'
 #' Retrieve IDs for particular entries or all entries in a table
+#' 
+#' @keywords internal
 #'
 #' @param table a \code{string} specifying the name of the table
 #' @param query a \code{list} containing a valid query for the table, *e.g.*
@@ -12,7 +14,7 @@
 #'
 get_id <- function(table,
                    query = list(),
-                   endpoint = "http://localhost:8000/api/") {
+                   endpoint = "http://127.0.0.1:8000/api/") {
 
   output <- get_entry(table, query, endpoint)
 
