@@ -6,7 +6,7 @@
 #' @return a character vector of tables
 #' @keywords internal
 #'
-get_tables <- function(endpoint = "http://localhost:8000/api/") {
+get_tables <- function(endpoint = "http://127.0.0.1:8000/api/") {
 
   httr::GET(endpoint) %>%
     httr::content(as = "text", encoding = "UTF-8") %>%
