@@ -2,6 +2,8 @@
 #'
 #' Upload information to the \code{quality_controlled} table in the data
 #' registry
+#' 
+#' @keywords internal
 #'
 #' @param object_url a \code{string} specifying the URL of an \code{object}
 #' @param endpoint a \code{string} specifying the registry endpoint
@@ -9,7 +11,7 @@
 #' @family new functions
 #'
 new_quality_controlled <- function(object_url,
-                                   endpoint = "http://localhost:8000/api/") {
+                                   endpoint = "http://127.0.0.1:8000/api/") {
 
   post_data(table = "quality_controlled",
             data = list(object = object_url),
