@@ -1,6 +1,8 @@
 #' Post entry to storage_root table
 #'
 #' Upload information to the \code{storage_root} table in the data registry
+#' 
+#' @keywords internal
 #'
 #' @param root a \code{string} specifying the URI of a
 #' \code{storage_location}, which when prepended to a \code{storage_location}
@@ -13,7 +15,7 @@
 #'
 new_storage_root <- function(root,
                              local,
-                             endpoint = "http://localhost:8000/api/") {
+                             endpoint = "http://127.0.0.1:8000/api/") {
 
   data <- list(root = root)
 
