@@ -5,7 +5,7 @@ library(rDataPipeline)
 # registry and CLI being installed and will therefore fail.
 
 if (Sys.getenv("_RUN_TESTS_") != "") {
-  Sys.setenv(FDP_endpoint = "http://localhost:8000/api/")
+  Sys.setenv(FDP_endpoint = "http://127.0.0.1:8000/api/")
   endpoint <- Sys.getenv("FDP_endpoint")
   testthat::test_check("rDataPipeline")
 }
